#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const literator_2_1 = require("./literator-2");
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const cosmiconfig_1 = require("cosmiconfig");
const cosmiconfig_typescript_loader_1 = require("@endemolshinegroup/cosmiconfig-typescript-loader");
const cli_common_1 = require("cli-common");
const package_json = fs_extra_1.readJSONSync(path_1.resolve(__dirname, "../../package.json"));
program.version(package_json.version);
program.command("help").action(() => {
    program.help();
});
program.command("dev").action(() => {
    // find config
    const explorer = cosmiconfig_1.cosmiconfig("typedraft", {
        searchPlaces: [`typedraft.config.ts`],
        loaders: {
            ".ts": cosmiconfig_typescript_loader_1.default,
        },
    });
    explorer.search().then(config_info => {
        let config = { DSLs: [], DraftPlugins: [], Targets: [] };
        if (config_info && !config_info.isEmpty) {
            config = Object.assign(Object.assign({}, config), config_info.config);
        }
        config.Targets.forEach(({ src, dest, baseDir }) => {
            const devConfig = {
                rename: {
                    extension: "ts",
                },
                transform(path, code) {
                    if (path.endsWith(".tsx")) {
                        const result = literator_2_1.ComposeFile(code, config);
                        return result;
                    }
                    else {
                        return code;
                    }
                },
            };
            if (baseDir) {
                devConfig.baseDir = baseDir;
            }
            cli_common_1.dev(src, dest, devConfig);
        });
    });
});
program.parse(process.argv);
