"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const traverse = require("filewalker");
const node_watch_1 = require("node-watch");
const fs_extra_1 = require("fs-extra");
const src_1 = require("../src");
function MakeTranscriberWithConfig(code, config) {
    const transcriber = src_1.MakeDefaultTranscriber(code);
    config.DSLs.forEach(({ name, dsl }) => {
        transcriber.AddDSL(name, dsl());
    });
    if (config.DraftPlugins.length !== 0) {
        transcriber.m_Plugins = config.DraftPlugins.map(PluginConstructor => Reflect.construct(PluginConstructor, [transcriber]));
    }
    return transcriber;
}
exports.MakeTranscriberWithConfig = MakeTranscriberWithConfig;
/**
 *
 */
function TraverseDirectory(path, callback) {
    const action = (relative, stats, absolute) => callback(relative, absolute);
    traverse(path)
        .on("file", action)
        .on("error", error => console.log(error))
        .walk();
}
function InspectDirectory(path, config) {
    ComposeDirectory(path, config);
    node_watch_1.default(path, { recursive: true }, (event, name) => {
        if (name.endsWith(".tsx")) {
            console.log(event, name);
            try {
                ComposeFile(name, config);
            }
            catch (error) {
                console.log(error.message);
            }
        }
    });
}
exports.InspectDirectory = InspectDirectory;
function InspectFile(path, config) {
    ComposeFile(path, config);
    node_watch_1.default(path, (event, name) => {
        if (name.endsWith(".tsx")) {
            console.log(event, name);
            try {
                ComposeFile(name, config);
            }
            catch (error) {
                console.log(error.message);
            }
        }
    });
}
exports.InspectFile = InspectFile;
function ComposeDirectory(path, config) {
    TraverseDirectory(path, (relative, absolute) => {
        if (absolute.endsWith(".tsx")) {
            try {
                ComposeFile(absolute, config);
            }
            catch (error) {
                console.log(`compose file failed: ${error.message}, source: ${relative}`);
            }
        }
    });
}
exports.ComposeDirectory = ComposeDirectory;
function CrossoutDirectory(path) {
    TraverseDirectory(path, (relative, absolute) => {
        if (absolute.endsWith(".tsx")) {
            fs_extra_1.removeSync(absolute.replace(".tsx", ".ts"));
        }
    });
}
exports.CrossoutDirectory = CrossoutDirectory;
function ComposeFile(source, config) {
    const code = fs_extra_1.readFileSync(source, "utf8");
    const transcriber = config
        ? MakeTranscriberWithConfig(code, config)
        : src_1.MakeDefaultTranscriber(code);
    const result = transcriber.Transcribe();
    fs_extra_1.outputFileSync(source.replace(".tsx", ".ts"), result, "utf8");
}
exports.ComposeFile = ComposeFile;
